# Part of Odoo. See LICENSE file for full copyright and licensing details.
from . import template_ch
from . import account_invoice
from . import account_journal
from . import res_bank
from . import ir_actions_report
from . import account_payment
